[−][src]Macro root_io::stream_zip
Zip n streams together analogous to the zip() function. This
is useful when iterating over multiple branches of a TTree. See
the examples of this crate for the suggested use-case.
Zip n streams together analogous to the zip() function. This
is useful when iterating over multiple branches of a TTree. See
the examples of this crate for the suggested use-case.